@@ -17,7 +17,7 @@ build_time_vars = {'ABIFLAGS': '',
               '-pthread -shared '
               '-L/tinderbox/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
               '-L/tinderbox/buildslave/build/workdir/LinkTarget/StaticLibrary '
-              '-flto=6 -fuse-linker-plugin -O2',
+              '-flto=5 -fuse-linker-plugin -O2',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-pc-linux-gnu',
@@ -40,9 +40,10 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CPPFLAGS': '',
  'CONFIGURE_LDFLAGS': '-L/tinderbox/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
                       '-L/tinderbox/buildslave/build/workdir/LinkTarget/StaticLibrary '
-                      '-flto=6 -fuse-linker-plugin -O2',
+                      '-flto=5 -fuse-linker-plugin -O2',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--prefix=/python-inst' '--with-system-expat' "
+ 'CONFIG_ARGS': "'--build=x86_64-pc-linux-gnu' '--host=x86_64-pc-linux-gnu' "
+                "'--prefix=/python-inst' '--with-system-expat' "
                 "'--enable-shared' "
                 "'--with-openssl=/tinderbox/buildslave/build/workdir/UnpackedTarball/openssl' "
                 "'PKG_CONFIG_LIBDIR=/tinderbox/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu' "
@@ -51,7 +52,9 @@ build_time_vars = {'ABIFLAGS': '',
                 "'CFLAGS=   ' "
                 "'LDFLAGS=-L/tinderbox/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs "
                 '-L/tinderbox/buildslave/build/workdir/LinkTarget/StaticLibrary '
-                "-flto=6 -fuse-linker-plugin -O2' "
+                "-flto=5 -fuse-linker-plugin -O2' "
+                "'build_alias=x86_64-pc-linux-gnu' "
+                "'host_alias=x86_64-pc-linux-gnu' "
                 "'PKG_CONFIG=/usr/bin/pkg-config'",
  'CONFINCLUDEDIR': '/python-inst/include',
  'CONFINCLUDEPY': '/python-inst/include/python3.8',
@@ -540,7 +543,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LDCXXSHARED': '/usr/bin/ccache g++ -pthread -shared',
  'LDFLAGS': '-L/tinderbox/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
             '-L/tinderbox/buildslave/build/workdir/LinkTarget/StaticLibrary '
-            '-flto=6 -fuse-linker-plugin -O2',
+            '-flto=5 -fuse-linker-plugin -O2',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.8.so',
  'LDLIBRARYDIR': '',
@@ -549,7 +552,7 @@ build_time_vars = {'ABIFLAGS': '',
              '-pthread -shared '
              '-L/tinderbox/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
              '-L/tinderbox/buildslave/build/workdir/LinkTarget/StaticLibrary '
-             '-flto=6 -fuse-linker-plugin -O2',
+             '-flto=5 -fuse-linker-plugin -O2',
  'LDVERSION': '3.8',
  'LIBC': '',
  'LIBDEST': '/python-inst/lib/python3.8',
@@ -666,12 +669,12 @@ build_time_vars = {'ABIFLAGS': '',
                    '-I./Include/internal -I. -I./Include -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-L/tinderbox/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
                     '-L/tinderbox/buildslave/build/workdir/LinkTarget/StaticLibrary '
-                    '-flto=6 -fuse-linker-plugin -O2',
+                    '-flto=5 -fuse-linker-plugin -O2',
  'PY_CPPFLAGS': '-I. -I./Include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-L/tinderbox/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
                '-L/tinderbox/buildslave/build/workdir/LinkTarget/StaticLibrary '
-               '-flto=6 -fuse-linker-plugin -O2',
+               '-flto=5 -fuse-linker-plugin -O2',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
